package com.bizmatics.system.controller.web;

import com.bizmatics.common.core.bean.ApiResult;
import com.bizmatics.common.core.exception.BusinessErrorCode;
import com.bizmatics.security.utils.SecurityUtils;
import com.bizmatics.system.controller.BaseController;
import com.bizmatics.system.model.SysDictType;
import com.bizmatics.system.model.page.TableDataInfo;
import com.bizmatics.system.service.ISysDictTypeService;
import com.bizmatics.system.service.constants.SystemConst;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 数据字典信息
 */
@RestController
@RequestMapping("/dict/type")
public class SysDictTypeController extends BaseController {
    @Autowired
    private ISysDictTypeService dictTypeService;

    @PreAuthorize("@ss.hasPermi('system:dict:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysDictType dictType) {
        startPage();
        List<SysDictType> list = dictTypeService.selectDictTypeList(dictType);
        return getDataTable(list);
    }

    /**
     * 查询字典类型详细
     */
    @PreAuthorize("@ss.hasPermi('system:dict:query')")
    @GetMapping(value = "/{dictId}")
    public ApiResult getInfo(@PathVariable Long dictId) {
        return ApiResult.success(dictTypeService.selectDictTypeById(dictId));
    }

    /**
     * 新增字典类型
     */
    @PreAuthorize("@ss.hasPermi('system:dict:add')")
    @PostMapping
    public ApiResult add(@Validated @RequestBody SysDictType dict) {
        if (SystemConst.NOT_UNIQUE.equals(dictTypeService.checkDictTypeUnique(dict))) {
            return ApiResult.error(BusinessErrorCode.BIZ_BUSINESS_ERROR.getCode(), "新增字典'" + dict.getDictName() + "'失败，字典类型已存在");
        }
        dict.setCreateBy(SecurityUtils.getUser().getName());
        return toAjax(dictTypeService.insertDictType(dict));
    }

    /**
     * 修改字典类型
     */
    @PreAuthorize("@ss.hasPermi('system:dict:edit')")
    @PutMapping
    public ApiResult edit(@Validated @RequestBody SysDictType dict) {
        if (SystemConst.NOT_UNIQUE.equals(dictTypeService.checkDictTypeUnique(dict))) {
            return ApiResult.error(BusinessErrorCode.BIZ_BUSINESS_ERROR.getCode(), "修改字典'" + dict.getDictName() + "'失败，字典类型已存在");
        }
        dict.setUpdateBy(SecurityUtils.getUser().getName());
        return toAjax(dictTypeService.updateDictType(dict));
    }

    /**
     * 删除字典类型
     */
    @PreAuthorize("@ss.hasPermi('system:dict:remove')")
    @DeleteMapping("/{dictIds}")
    public ApiResult remove(@PathVariable Long[] dictIds) {
        return toAjax(dictTypeService.deleteDictTypeByIds(dictIds));
    }

    /**
     * 清空缓存
     */
    @PreAuthorize("@ss.hasPermi('system:dict:remove')")
    @DeleteMapping("/clearCache")
    public ApiResult clearCache() {
        dictTypeService.clearCache();
        return ApiResult.success();
    }

    /**
     * 获取字典选择框列表
     */
    @GetMapping("/optionselect")
    public ApiResult optionselect() {
        List<SysDictType> dictTypes = dictTypeService.selectDictTypeAll();
        return ApiResult.success(dictTypes);
    }
}
