package com.bizmatics.system.controller.web;

import com.bizmatics.common.core.bean.ApiResult;
import com.bizmatics.common.core.util.BeanMapperUtils;
import com.bizmatics.model.SysFile;
import com.bizmatics.service.FileSerivce;
import com.bizmatics.service.dto.SysFileDTO;
import com.bizmatics.service.dto.SysFileQueryRequest;
import com.bizmatics.service.dto.SysFileUploadRequest;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.commons.CommonsMultipartFile;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

@Controller
@RequestMapping("sysFile")
public class SysFileController {

    private final FileSerivce fileSerivce;

    public SysFileController(FileSerivce fileSerivce) {
        this.fileSerivce = fileSerivce;
    }

    @PostMapping
    @ResponseBody
    public ApiResult<List<SysFileDTO>> uploadFile(
            @RequestParam("files") CommonsMultipartFile[] multipartFiles,
            @RequestParam("batchNo") String batchNo,
            @RequestParam("businessType") String businessType,
            @RequestParam(value = "ossacl", required = false) OSSACL ossacl,
            @RequestParam(name = "uploadType", required = false) UploadType uploadType,
            @RequestParam(name = "expireAt", required = false) Date expireAt) {
        SysFileUploadRequest request = SysFileUploadRequest.builder()
                .multipartFiles(Arrays.asList(multipartFiles))
                .batchNo(batchNo)
                .businessType(businessType)
                .ossAcl(ossacl)
                .uploadType(uploadType)
                .expireAt(expireAt)
                .build();
        if (uploadType == null) {
            request.setUploadType(UploadType.File);
        }
        List<com.bizmatics.system.service.dto.SysFileDTO> sysFileDTOList = fileSerivce.addFile(request);
        List<SysFileDTO> sysFileDTOS = BeanMapperUtils.mapList(sysFileDTOList, com.bizmatics.system.service.dto.SysFileDTO.class, SysFileDTO.class);
        return ApiResult.success(sysFileDTOS);
    }

    @GetMapping
    @ResponseBody
    public ApiResult<List<SysFile>> getFile(SysFileQueryRequest sysFileQueryRequest) {
        List<SysFile> sysFileList = BeanMapperUtils.mapList(fileSerivce.getFile(sysFileQueryRequest), com.bizmatics.system.model.SysFile.class, SysFile.class);
        return ApiResult.success(sysFileList);
    }

    @GetMapping("/generateBatchNo")
    @ResponseBody
    public ApiResult<String> generateBatchNo() {
        return ApiResult.success(fileSerivce.generateBatchNo());
    }

}
