package com.bizmatics.service;

import com.bizmatics.common.mvc.base.CrudService;
import com.bizmatics.model.SysFile;
import com.bizmatics.service.dto.SysFileDTO;
import com.bizmatics.service.dto.SysFileQueryRequest;
import com.bizmatics.service.dto.SysFileUploadRequest;
import org.springframework.web.multipart.commons.CommonsMultipartFile;

import java.util.Date;
import java.util.List;

/**
 * 文件服务
 */
public interface FileSerivce extends CrudService<SysFile> {
    /**
     * 添加文件到sysfile
     * 可以同时长传多个文件. 但相比V2,不能够指定key. key随机生成.
     * @param sysFileUploadRequest
     * @return
     */
    List<SysFileDTO> addFile(SysFileUploadRequest sysFileUploadRequest);

    /**
     * 添加文件. V2
     * <p>
     * 字段multipartFiles/urls的元素个数只能有1个.
     * 允许调用方指定key.
     * 如果一个批次需要上传多个文件, 则多次调用.
     *
     * @param sysFileUploadRequest
     * @return
     */
    SysFileDTO addFileV2(SysFileUploadRequest sysFileUploadRequest);

    /**
     * 添加multipart file
     * @param m
     * @param sysFileUploadRequest
     * @return
     */
    SysFileDTO uploadMultipartFile(CommonsMultipartFile m, SysFileUploadRequest sysFileUploadRequest);

    /**
     * 添加链接
     * @param url
     * @param sysFileUploadRequest
     * @return
     */
    SysFileDTO addExternalLink(String url, SysFileUploadRequest sysFileUploadRequest);

    /**
     * 添加链接对应的文件
     * @param url
     * @param sysFileUploadRequest
     * @return
     */
    SysFileDTO uploadExternalFile(String url, SysFileUploadRequest sysFileUploadRequest);

    /**
     * 生成新的batchNo
     * @return
     */
    String generateBatchNo();

    /**
     * 确认文件生效
     * @param batchNo
     * @param fileIds
     * @return
     */
    Boolean active(String batchNo, List<String> fileIds);

    /**
     * 获取文件
     * @param sysFileRequest
     * @return
     */
    List<SysFile> getFile(SysFileQueryRequest sysFileRequest);


    /**
     * 根据时间获取失效文件
     *
     * @param date
     * @return
     */
    List<SysFile> getFileByExpireAt(Date date);

    /**
     * 批量删除文件(更新文件删除状态)
     *
     * @param sysFiles
     * @return
     */
    Integer deleteFiles(List<SysFile> sysFiles);

    /**
     * 清理垃圾文件.
     *
     * @param fileList
     * @return
     */
    Integer clearFiles(List<SysFile> fileList);

    /**
     * 通过batchNo删除
     *
     * @param batchNo
     * @return
     */
    Integer removeByBatchNo(String batchNo);

}
