package com.bizmatics.service.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.bizmatics.common.core.bean.CommonPage;
import com.bizmatics.common.core.exception.BusinessException;
import com.bizmatics.common.core.util.BeanMapperUtils;
import com.bizmatics.common.core.util.StringUtils;
import com.bizmatics.common.core.util.id.IdWorker;

import com.bizmatics.common.mvc.base.AbstractCrudService;
import com.bizmatics.model.SysAsyncTask;
import com.bizmatics.model.SysDictData;
import com.bizmatics.model.vo.SysAsyncTaskVo;
import com.bizmatics.persistence.mapper.SysAsyncTaskMapper;
import com.bizmatics.service.ISysAsyncTaskService;
import com.bizmatics.service.ISysConfigService;
import com.bizmatics.service.ISysDictDataService;
import com.bizmatics.service.dto.SysAsyncTaskDTO;
import com.bizmatics.service.expcetion.AsyncErrorCode;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author fanzhiqiang
 */
@Service
@AllArgsConstructor
public class SysAsyncTaskServiceImpl extends AbstractCrudService<SysAsyncTaskMapper, SysAsyncTask> implements ISysAsyncTaskService {

    private final IdWorker idWorker;
    private final ISysDictDataService dictDataService;
    private final ISysConfigService sysConfigService;

    @Override
    public Long getId(String userId, String userName, String funcType) {
        SysDictData sysDictData = dictDataService.selectDictLabel("sys.async.funcType", funcType);
        if (sysDictData == null) {
            throw new BusinessException(AsyncErrorCode.OPERATION_TYPE_NOT_EXIST, "sys.async.funcType");
        }
        int limit = Integer.parseInt(sysConfigService.selectConfigByKey("sys.async.operationLimit"));
        Long id;
        Calendar c = Calendar.getInstance();
        c.setTime(new Date());
        c.add(Calendar.HOUR, -1);
        Integer count = baseMapper.getCountByUserIdAndFuncTypeAndCreateTime(userId, funcType, c.getTime());
        if (count != null && count >= limit) {
            throw new BusinessException(AsyncErrorCode.ASYNC_OUT_OF_OPERATIONS);
        }
        id = idWorker.nextId();
        SysAsyncTask sysAsyncTask = new SysAsyncTask();
        sysAsyncTask.setStartTime(new Date());
        sysAsyncTask.setId(id);
        sysAsyncTask.setCreateUserId(userId);
        sysAsyncTask.setCreateUserName(userName);
        sysAsyncTask.setFuncType(funcType);
        save(sysAsyncTask);
        return id;
    }


    @Override
    public CommonPage<SysAsyncTaskVo> getList(Long asyncTaskId, Date startTime, Date endTime, String funcType, Boolean user, Integer current, Integer size) {
        Page<SysAsyncTask> page = new Page<>(current, size);
        String loginUserId = null;
        page = page(page, Wrappers.lambdaQuery(SysAsyncTask.class).eq(asyncTaskId != null, SysAsyncTask::getId, asyncTaskId).ge(startTime != null, SysAsyncTask::getStartTime,
                startTime).le(endTime != null, SysAsyncTask::getStartTime, endTime).eq(StringUtils.isNotBlank(funcType), SysAsyncTask::getFuncType, funcType).eq(user != null && user, SysAsyncTask::getCreateUserId, loginUserId));

        List<SysAsyncTaskVo> voList = new ArrayList<>();
        for (SysAsyncTask record : page.getRecords()) {
            SysAsyncTaskVo vo = new SysAsyncTaskVo();
            BeanMapperUtils.copy(record, vo);
            vo.setIdStr(String.valueOf(record.getId()));
            voList.add(vo);
        }
        return new CommonPage<>(voList, page.getTotal(), page.getSize(), page.getCurrent());
    }

    @Override
    public void sendResult(Long id, Boolean isSuccess, String result, AsyncResultType resultType) {
        SysAsyncTask sysAsyncTask = new SysAsyncTask();
        sysAsyncTask.setId(id);
        sysAsyncTask.setIsSuccess(isSuccess);
        sysAsyncTask.setResult(result);
        sysAsyncTask.setResultType(resultType.name());
        if (Objects.equals(AsyncResultType.FILE, resultType)) {
            sysAsyncTask.setResultKey(result);
        }
        sysAsyncTask.setEndTime(new Date());
        baseMapper.updateById(sysAsyncTask);
    }

    @Override
    public void sendResult(SysAsyncTaskDTO dto) {
        SysAsyncTask sysAsyncTask = new SysAsyncTask();
        BeanMapperUtils.copy(dto, sysAsyncTask);
        sysAsyncTask.setEndTime(new Date());
        baseMapper.updateById(sysAsyncTask);
    }
}
