package com.bizmatics.service.util;

import com.bizmatics.common.spring.config.redis.RedisHelper;
import com.bizmatics.common.spring.util.SpringContextUtils;
import com.bizmatics.model.SysDictData;
import com.bizmatics.service.constants.CacheConst;
import org.springframework.stereotype.Component;

import java.util.Collection;
import java.util.List;
import java.util.Objects;

/**
 * 字典工具类
 */
@Component
public class DictUtils {

    private static RedisHelper redisHelper;

    /**
     * 设置字典缓存
     *
     * @param key       参数键
     * @param dictDatas 字典数据列表
     */
    public static void setDictCache(String key, List<SysDictData> dictDatas) {
        RedisHelper redisHelper = getRedisHelper();
        redisHelper.set(getCacheKey(key), dictDatas);
    }

    /**
     * 获取字典缓存
     *
     * @param key 参数键
     * @return dictDatas 字典数据列表
     */
    public static List<SysDictData> getDictCache(String key) {
        Object cacheObj = getRedisHelper().get(getCacheKey(key));
        if (Objects.nonNull(cacheObj)) {
            List<SysDictData> DictDatas = (List<SysDictData>) cacheObj;
            return DictDatas;
        }
        return null;
    }

    /**
     * 清空字典缓存
     */
    public static void clearDictCache() {
        Collection<String> keys = getRedisHelper().keys(CacheConst.SYS_DICT_KEY + "*");
        getRedisHelper().delete(keys);
    }

    /**
     * 设置cache key
     *
     * @param configKey 参数键
     * @return 缓存键key
     */
    public static String getCacheKey(String configKey) {
        return CacheConst.SYS_DICT_KEY + configKey;
    }

    private static RedisHelper getRedisHelper() {
        return DictUtils.redisHelper == null ? SpringContextUtils.getBean(RedisHelper.class) : DictUtils.redisHelper;
    }

}
